set no prompt ; Turn off prompt display.

; This m4 Mathomatic input file is used by the shell scripts "matho" and "rmath".

; m4 macro definitions for some elementary math functions and constants in Mathomatic.
m4_define(`sqrt', `(($1)**.5)'); function sqrt(x) = square root of x
m4_define(`Sqrt', m4_defn(`sqrt')); Allow Sqrt(x) for Mathematica compatibility
m4_define(`cbrt', `(($1)**(1/3))'); function cbrt(x) = cube root of x
m4_define(`Cbrt', m4_defn(`cbrt'));
m4_define(`exp', `(e**($1))'); function exp(x) = e^x
m4_define(`Exp', m4_defn(`exp'));
m4_define(`pow', `(($1)**($2))'); function pow(x, y) = x^y
m4_define(`Pow', m4_defn(`pow'));
m4_define(`abs', `(|($1)|)'); function abs(x) = absolute value = |x|
m4_define(`Abs', m4_defn(`abs'));
m4_define(`phi', `((1+5**.5)/2)'); phi = the golden ratio constant
m4_define(`Phi', m4_defn(`phi'));

set modulus_mode=2 ; mode 1 or 2 required for floor() and ceil().
m4_define(`floor', `(($1)-($1)%1)'); floor(x) = floor function, real x -> integer result
m4_define(`Floor', m4_defn(`floor'));
m4_define(`ceil', `(($1)+(-($1))%1)'); ceil(x) = ceiling function, real x -> integer result
m4_define(`Ceil', m4_defn(`ceil'));
m4_define(`int', `(($1)//1)'); int(x) = truncate to integer, real x -> integer result
m4_define(`Int', m4_defn(`int'));
m4_define(`round', `((($1)+|($1)|/($1)/2)//1)'); round(x) = round to nearest integer; beware, round(0) fails.
m4_define(`Round', m4_defn(`round'));

; Standard trigonometry functions as complex exponentials follow.
; Based on Euler's identity: e^(i*x) = cos(x) + i*sin(x)
; Argument x is in radians.
m4_define(`sin', `((e**(i*($1))-e**(-i*($1)))/(2i))'); sin(x) = sine of x
m4_define(`Sin', m4_defn(`sin'));
m4_define(`cos', `((e**(i*($1))+e**(-i*($1)))/2)'); cos(x) = cosine of x
m4_define(`Cos', m4_defn(`cos'));
m4_define(`tan', `((e**(i*($1))-e**(-i*($1)))/(i*(e**(i*($1))+e**(-i*($1)))))'); tan(x) = tangent of x
m4_define(`Tan', m4_defn(`tan'));
m4_define(`cot', `(i*(e**(i*($1))+e**(-i*($1)))/(e**(i*($1))-e**(-i*($1))))'); cot(x) = cotangent of x
m4_define(`Cot', m4_defn(`cot'));
m4_define(`sec', `(2/(e**(i*($1))+e**(-i*($1))))'); sec(x) = secant of x
m4_define(`Sec', m4_defn(`sec'));
m4_define(`csc', `(2i/(e**(i*($1))-e**(-i*($1))))'); csc(x) = cosecant of x
m4_define(`Csc', m4_defn(`csc'));

; Standard hyperbolic trigonometry functions follow.
; Available are sinh(x), cosh(x), tanh(x), coth(x), sech(x), and csch(x).
; These are related to the above trigonometry functions without the "h" appended to the function name.
m4_define(`sinh', `((e**($1)-e**-($1))/2)')
m4_define(`Sinh', m4_defn(`sinh'));
m4_define(`cosh', `((e**($1)+e**-($1))/2)')
m4_define(`Cosh', m4_defn(`cosh'));
m4_define(`tanh', `((e**($1)-e**-($1))/(e**($1)+e**-($1)))')
m4_define(`Tanh', m4_defn(`tanh'));
m4_define(`coth', `((e**($1)+e**-($1))/(e**($1)-e**-($1)))')
m4_define(`Coth', m4_defn(`coth'));
m4_define(`sech', `(2/(e**($1)+e**-($1)))')
m4_define(`Sech', m4_defn(`sech'));
m4_define(`csch', `(2/(e**($1)-e**-($1)))')
m4_define(`Csch', m4_defn(`csch'));

echo Functions are now available.
set prompt
